==> gsf-0.2.1.tar.bz2: gsf-0.2.1/src/sound.h <==
/*
 *      sound.h
 *      
 *      Copyright 2009 - 2010 Alex <alex@linuxonly.ru>
 *      
 *      This program is free software: you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __SOUND_H__
#define __SOUND_H__

#include <glib.h>
#include "mainwindow.h"

enum {
	SOUND_PARAMETER_SNR = 0,
	SOUND_PARAMETER_AGC,
	SOUND_PARAMETER_BER
};

enum {
	SOUND_LANGUAGE_MULTIPLEX_10 = 0,
	SOUND_LANGUAGE_MULTIPLEX_100,
	SOUND_LANGUAGE_MULTIPLEX_VOID
};

struct _soundmodule {
	guint id;
	gchar *name;
	gint version;
	gchar *path;
};

struct _soundlanguage {
	gchar *code;
	gchar multiplex;
};

gboolean sound_languages_set_language(guint languageid);
void sound_limit_set(guchar limit);
guint sound_limit_get(void);
void sound_parameter_set(guchar parameter);
guint sound_parameter_get(void);
GSList *sound_modules_get(guint *index);
GSList *sound_languages_get(guint *index);
gboolean sound_init(void);
gboolean sound_play(struct _frontend *frontend, gulong timeout);

#endif /* __SOUND_H__ */

==> gsf-0.2.2.tar.bz2: gsf-0.2.2/src/sound.h <==
/*
 *      sound.h
 *      
 *      Copyright 2009 - 2010 Alex <alex@linuxonly.ru>
 *      
 *      This program is free software: you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __SOUND_H__
#define __SOUND_H__

#include <glib.h>
#include "mainwindow.h"

enum {
	SOUND_PARAMETER_SNR = 0,
	SOUND_PARAMETER_AGC,
	SOUND_PARAMETER_BER
};

enum {
	SOUND_LANGUAGE_MULTIPLEX_10 = 0,
	SOUND_LANGUAGE_MULTIPLEX_100_SIMPLE,
	SOUND_LANGUAGE_MULTIPLEX_100_FULL,
	SOUND_LANGUAGE_MULTIPLEX_VOID
};

struct _soundmodule {
	guint id;
	gchar *name;
	gint version;
	gchar *path;
};

struct _soundlanguage {
	gboolean islocale;
	gboolean flagexists;
	gchar *name;
	gchar *nativename;
	gchar *code;
	gchar multiplex;
};

//gboolean sound_languages_set_language(guint languageid);
gboolean sound_languages_set_language(gchar *code);
gchar *sound_languages_flag_path(gchar *code);
void sound_limit_set(guchar limit);
guint sound_limit_get(void);
void sound_parameter_set(guchar parameter);
guint sound_parameter_get(void);
GSList *sound_modules_get(guint *index);
//GSList *sound_languages_get(guint *index);
GSList *sound_languages_get(gint *index);
gboolean sound_init(void);
gboolean sound_play(struct _frontend *frontend, gulong timeout);

#endif /* __SOUND_H__ */
